# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [1.14.0] - 2021-05-17
### Changed
- `UKI-SOUTHGRID-OX-HEP-disk` is marked as broken, since the SE will be switched off
